``pygcam.mcs.worker``
============================

This module provides support for running an MCS trial on an
ipython parallel cluster's engine.

API
---

.. automodule:: pygcam.mcs.worker
   :members:

